function [selected_chs, selected_peaks] = selectChanlsPeaks(cor1, lags, thrs1)
%
% Function for selecting channels and peaks
% This is implementation of "A multipitch Tracking algorithm for noisy speech" by Mingyang Wu.
%
% cor1 and cor2 are the normalized correlogram calculated with different length of window.
% lowchs and highchs are starting and ending channel corresponding to low-freq or high-freq. channels.
%
% kslee@ee.columbia.edu, 6/25/2005
% [2011-05-07] Byung Suk Lee bsl@ee.columbia.edu

if nargin < 2
    lags = (1:400);
end
if nargin < 3    
    thrs1 = 0.945;
end
[nch, nlag] = size(cor1);

% Finding magnitudes and locations(time lags) of peaks greater than 0.2 in correlation
[locl, val1, maxloc1, maxval1] = getpeaks(cor1, lags); %25ms length of window

selected_chs = zeros(nch,1);
selected_peaks = zeros(nch, size(locl,2));

% Channel selection --------------------------------------------------------------
for ch = 1:nch
    selected_chs(ch) = (maxval1(ch) > thrs1);
        
    % Include all time lags of peaks in selected channels.
    if selected_chs(ch) == 1
        selected_peaks(ch,:) = locl(ch,:);
        selected_peaks_values(ch,:) = val1(ch,:);
    end
    
end  


